# libpythonpro

Módulo para exemplificar a construção de um projeto Python do curso PyTools

Contribuindo via git teste!

Link do Curso [Python Pro ] (https://www.python.pro.br/)

[![Build Status](https://travis-ci.org/LeandroBP/libpythonpro.svg?branch=master)](https://travis-ci.org/LeandroBP/libpythonpro)
[![Updates](https://pyup.io/repos/github/LeandroBP/libpythonpro/shield.svg)](https://pyup.io/repos/github/LeandroBP/libpythonpro/)
[![Python 3](https://pyup.io/repos/github/LeandroBP/libpythonpro/python-3-shield.svg)](https://pyup.io/repos/github/LeandroBP/libpythonpro/)

Suportada a versão 3 do Python

Para instalar:

``` console
python3 -m venv .venv
source .venv/bin/activate
pip install -r requeriments-dev.txt
```
Para conferir a qualidade do código:

``` console
flake8
```